/*
	$Id: ScanTransfer.java 4478 2008-09-05 15:15:54Z jari $

	Copyright (C) 2005 Gregory Vincic
	Copyright (C) 2006 Jari Hakkinen, Nicklas Nordborg, Gregory Vincic
	Copyright (C) 2007 Jari Hakkinen, Martin Svensson

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or modify it
	under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 3 of the License, or
	(at your option) any later version.

	BASE is distributed in the hope that it will be useful, but
	WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
	General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
	02111-1307, USA.
*/

package net.sf.basedb.clients.migrate;

import net.sf.basedb.core.BaseException;
import net.sf.basedb.core.CommonItem;
import net.sf.basedb.core.DbControl;
import net.sf.basedb.core.Hardware;
import net.sf.basedb.core.Hybridization;
import net.sf.basedb.core.Scan;
import java.sql.ResultSet;
import java.sql.SQLException;

/**
This class provides methods for transferring ScanTransfer from base 1 to BASE
2.

@author Gregory, Martin
@version 2.0
@base.modified $Date: 2008-09-05 17:15:54 +0200 (Fri, 05 Sep 2008) $
*/

public class ScanTransfer extends CommonItemTransfer
{
	/**
	Logger for this class
	 */
	private static final org.apache.log4j.Logger log = org.apache.log4j.Logger.getLogger("net.sf.basedb.clients.migrate.ScanTransfer");
	
	HybridizationTransfer hybridizationT = null;
	HardwareTransfer hardwareT = null;

	/**
	Constructs a new ScanTransfer.
	 */
	ScanTransfer(UserTransfer userT, GroupTransfer groupT,
			HybridizationTransfer hybridizationT, HardwareTransfer hardwareT)
	{
		super(userT, groupT);
		log.debug("Checking that necessary transfers have been done before proceeding with Scan");
		if (hybridizationT.isDone() && hardwareT.isDone())
		{
			this.hybridizationT = hybridizationT;
			this.hardwareT = hardwareT;
		}
		else
		{
			if (!hybridizationT.isDone()) log.debug("Dependency: Hybridizations haven't been transfered");
			if (!hardwareT.isDone()) log.debug("Dependency: Hardwares haven't been transfered");
			dependencyFailure();
		}
	}

	public void start()
	{
		log.info("Transferring Scans...");
		int count = getInt("countScans");
		initIdMap(count);
		startProgress(count, "Scans");
		run(prepareStatementFromFile("selectScans"), 0, getBatchSize());
		done();
		log.info("Transferring Scans...DONE");
	}

	/**
	Creates a {@link Scan} from the current position in
	<code>ResultSet</code>.
	
	@param b2c {@link DbControl} used to transfer this item
	@param rs <code>ResultSet</code> containing the data for this item.
	@return <code>Scan</code>
	@throws BaseException If a new Scan cannot be created.
	@throws SQLException If current ResultSet position is invalid or number
	        of columns in the select statement is to low.
	 */
	protected Scan createItem(DbControl b2c, ResultSet rs)
			throws BaseException, SQLException
	{
		Hybridization hybridization = hybridizationT.getHybridizationById(
				b2c, rs.getInt(9));
		if (hybridization != null)
		{
			Scan scan = Scan.getNew(b2c, hybridization);
			setCommonItemData(b2c, (CommonItem) scan, rs);
			Hardware scanner = hardwareT.getHardwareById(b2c, rs.getInt(11));
			if (scanner != null)
			{
				scan.setScanner(scanner);
			}
			// Protocol is not available in base 1
			if (log.isDebugEnabled())
			{
				log.debug("Transfered Scan: " + scan.getName() + "\tBASE1 id(" + rs.getInt(1) + ")");
				log.debug("--------------------------------------------------------------------------");
			}
			return scan;
		}
		log.debug("No hybridization with id: " + rs.getInt(9) + " could be found");
		return null;
	}

	/**
	Returns a Scan by the given base 1 scan(ImageAcquisition) id.
	
	@param dbc <code>DbControl</code> used to get the Scan.
	@param base1ScanId
	@return <code>Scan</code> or null if the given scan id does not exsist.
	 */
	public Scan getScanById(DbControl dbc, int base1ScanId)
	{
		try
		{
			Integer base2Id = getBase2Id(base1ScanId);
			return base2Id == null ? null : Scan.getById(dbc, base2Id);
		}
		catch (BaseException e)
		{
			log.warn("Couldn't get Scan with id " + base1ScanId + " in BASE1");
			if (log.isDebugEnabled()) log.debug("\t" + e);
		}
		return null;
	}
}
