/*
	$Id: WebException.java 4478 2008-09-05 15:15:54Z jari $

	Copyright (C) 2005 Nicklas Nordborg
	Copyright (C) 2006 Jari Hakkinen, Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place - Suite 330,
	Boston, MA  02111-1307, USA.
*/
package net.sf.basedb.clients.web;

import net.sf.basedb.util.Values;
import net.sf.basedb.clients.web.taglib.Page;
/**
	This exception can be thrown on any JSP page in BASE. It will be catched
	by the server and execution is transferred to <code>/exception/web.jsp</code>
	page which will display the error message in a user friendly format.

	@author Nicklas
	@version 2.0
*/
public class WebException
	extends Exception
{

	/**
		
	*/
	private static final long serialVersionUID = 8401139016420733632L;

	/**
		The title of the error message.
	*/
	private String title;

	/**
		A more detailed description of the error message.
	*/
	private String detail;

	/**
		The type of page to display the error message in.
	*/
	private String pageType;

	/**
		Create a new <code>WebException</code>.
		@param pageType The type of page to use for the error message, the valid values are
			defined by the {@link Page &lt;base:page&lt;} taglib
		@param title The title of the error message
		@param detail A detailed description of the error
	*/
	public WebException(String pageType, String title, String detail)
	{
		this(pageType, title, detail, new Object[] {});
	}


	/**
		Create a new <code>WebException</code>.
		@param pageType The type of page to use for the error message, the valid values are
			defined by the {@link Page &lt;base:page&lt;} taglib
		@param title The title of the error message
		@param detail A detailed description of the error, including parameter
			placeholders of the form {1}, {2}, etc.
		@param parameters An array of parameters, which will replace the
			placeholders in the detailed message
	*/
	public WebException(String pageType, String title, String detail, Object... parameters)
	{
		super(title+":<br>"+detail);
		this.pageType = pageType;
		this.title = title;
		this.detail = Values.formatMessage(detail, parameters);
	}

	/**
		Get the page type to display the error message in. This value is used
		in the &lt;base:page type="..."&gt; tag.
	*/
	public String getPageType()
	{
		return pageType;
	}

	/**
		Get the title of the error message.
	*/
	public String getTitle()
	{
		return title;
	}

	/**
		Get the detailed description of the error message.
	*/
	public String getDetail()
	{
		return detail;
	}

}

