/**
	$Id: AbstractJspRendererFactory.java 4478 2008-09-05 15:15:54Z jari $

	Copyright (C) Authors contributing to this file.

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place - Suite 330,
	Boston, MA  02111-1307, USA.
*/
package net.sf.basedb.clients.web.extensions;

import net.sf.basedb.util.extensions.Action;
import net.sf.basedb.util.extensions.InvokationContext;
import net.sf.basedb.util.extensions.RendererFactory;

/**
	An abstract base class for action factories that may need
	to support adding scripts and stylesheets to the rendered
	JSP page. Most of this functionality is inherited from the
	{@link AbstractJspFactory} class.

	<p>
	Scripts and stylesheets that has been added to the factory will 
	be propagated to the {@link JspContext#addScript(String)}
	and {@link JspContext#addStylesheet(String)} methods in
	the {@link #prepareContext(InvokationContext)}.
	
	@author nicklas
	@version 2.7
	@base.modified $Date:2008-03-20 12:15:25 +0100 (Thu, 20 Mar 2008) $
*/
public abstract class AbstractJspRendererFactory<A extends Action>
	extends AbstractJspFactory
	implements RendererFactory<A>
{
	
	/**
		Create a new factory instance.
	*/
	public AbstractJspRendererFactory()
	{}
	
	/*
		From the ActionFactory interface
		--------------------------------
	*/
	/**
		If scripts and stylesheets has been added to the factory,
		propagates those to the {@link JspContext}. A subclass that 
		overrides this method should call <code>super.prepareContext()</code>.
	*/
	@Override
	public void prepareContext(InvokationContext<? extends A> context)
	{
		prepareContext((JspContext)context.getClientContext());
	}
	// ----------------------------------

}
