/**
	$Id: ExportedProperty.java 4478 2008-09-05 15:15:54Z jari $

	Copyright (C) 2006 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place - Suite 330,
	Boston, MA  02111-1307, USA.
*/
package net.sf.basedb.clients.web.plugins;

import net.sf.basedb.core.AnnotationType;
import net.sf.basedb.core.DbControl;
import net.sf.basedb.util.Values;
import net.sf.basedb.util.formatter.Formatter;

/**

 @author nicklas
 @version 2.2
 @base.modified $Date: 2008-09-05 17:15:54 +0200 (Fri, 05 Sep 2008) $
 */
public class ExportedProperty
{
	public final String name;
	public final String title;
	public final AnnotationType annotationType;
	public final Formatter formatter;
	
	public static ExportedProperty parse(DbControl dc, String column, boolean annotatable, Formatter formatter)
	{
		return parse(dc, column, null, annotatable, formatter);
	}

	/**
		@since 2.8
	*/
	public static ExportedProperty parse(DbControl dc, String column, String columnPrefix, boolean annotatable, Formatter formatter)
	{
		String[] p = column.split(":");
		String name = p[0];
		String title = p.length > 1 ? p[1] : p[0];
		AnnotationType at = null;
		if (name.startsWith("#") && annotatable) // && itemType != Item.SPOTDATA)
		{
			// Annotation: properties[i] = #annotationTypeId
			int annotationTypeId = Values.getInt(name.substring(1));
			at = AnnotationType.getById(dc, annotationTypeId);
			name = "annotationtype_"+annotationTypeId;
		}
		if (columnPrefix != null) title = columnPrefix + title;
		return new ExportedProperty(name, title, at, formatter);
	}

	
	public ExportedProperty(String name, String title, AnnotationType annotationType, Formatter formatter)
	{
		this.name = name;
		this.title = title;
		this.annotationType = annotationType;
		this.formatter = formatter;
	}
	
}
