/**
	$Id: ReporterScoreQueryWrapper.java 4478 2008-09-05 15:15:54Z jari $

	Copyright (C) 2006 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place - Suite 330,
	Boston, MA  02111-1307, USA.
*/
package net.sf.basedb.clients.web.plugins;

import net.sf.basedb.core.DbControl;
import net.sf.basedb.core.Metadata;
import net.sf.basedb.core.ReporterScore;
import net.sf.basedb.core.ReporterScoreQuery;
import net.sf.basedb.core.data.ReporterData;
import net.sf.basedb.core.data.ReporterListScoreData;
import net.sf.basedb.core.query.ResultIterator;

/**
	A query wrapper for {@link ReporterScoreQuery}:s.
	
	@author nicklas
	@version 2.2
	@base.modified $Date: 2008-09-05 17:15:54 +0200 (Fri, 05 Sep 2008) $
*/
public class ReporterScoreQueryWrapper
	implements QueryWrapper<ReporterScore>
{
	private final ReporterScoreQuery query;
	private final DbControl dc;
	private final Metadata metadata;

	/**
		Create a new query wrapper.
		@param dc The DbControl used to execute the query
		@param query The query
	*/
	public ReporterScoreQueryWrapper(DbControl dc, ReporterScoreQuery query)
	{
		this.dc = dc;
		this.query = query;
		this.metadata = Metadata.getInstance(ReporterListScoreData.class, 
			ReporterListScoreData.class.getName());
	}

	/**
		Calls {@link ReporterScoreQuery#iterate(DbControl)}
	*/
	public ResultIterator<ReporterScore> iterate()
	{
		return query.iterate(dc);
	}

	/**
		Calls {@link ReporterData#getId()}.
	*/
	public int getId(ReporterScore item)
	{
		return item.getReporter().getId();
	}

	/**
		Uses a {@link Metadata} object to get the value of the specified property.
	*/
	@SuppressWarnings("unchecked")
	public Object getData(ExportedProperty exportedProperty, ReporterScore item)
		throws Exception
	{
		return metadata.getPropertyValue(dc, item, exportedProperty.name);
	}

}
