/*
	$Id: CharacterEncodingFilter.java 4478 2008-09-05 15:15:54Z jari $

	Copyright (C) 2005 Nicklas Nordborg
	Copyright (C) 2006 Jari Hakkinen

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place - Suite 330,
	Boston, MA  02111-1307, USA.
*/
package net.sf.basedb.clients.web.servlet;

import javax.servlet.Filter;
import javax.servlet.FilterChain;
import javax.servlet.FilterConfig;
import javax.servlet.ServletRequest;
import javax.servlet.ServletResponse;
import javax.servlet.ServletException;
import java.io.IOException;

/**
	This is a filter that sets the character encoding for both the 
	request and the response. The default encoding is UTF-8.

	@author Nicklas
	@version 2.0
	@base.modified $Date: 2008-09-05 17:15:54 +0200 (Fri, 05 Sep 2008) $
*/
public final class CharacterEncodingFilter
	implements Filter
{

	private FilterConfig config = null;
	private String characterEncoding = "UTF-8";
	
	public void init(FilterConfig config)
	{
		this.config = config;
		if (config.getInitParameter("characterEncoding") != null)
		{
			characterEncoding = config.getInitParameter("characterEncoding");
		}
	}
	
	public void destroy()
	{
		config = null;
	}
	
	public void doFilter(ServletRequest request, ServletResponse response, FilterChain chain)
		throws IOException, ServletException
	{
		if (request.getCharacterEncoding() == null)
		{
			request.setCharacterEncoding(characterEncoding);
		}
		response.setContentType("text/html; charset="+characterEncoding);
		chain.doFilter(request, response);
	}
}
