/*
	$Id: Help.java 4478 2008-09-05 15:15:54Z jari $

	Copyright (C) 2006 Jari Hakkinen, Nicklas Nordborg, Martin Svensson

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place - Suite 330,
	Boston, MA  02111-1307, USA.
*/

package net.sf.basedb.clients.web.taglib;

import net.sf.basedb.util.Values;

import javax.servlet.jsp.JspException;
import javax.servlet.jsp.JspTagException;
import javax.servlet.jsp.tagext.TagSupport;

/**
  This tag is used to make it easier to add help features on a BASE web page.
  <p>
  <b>Example:<b>
  <pre>
  	&lt;%@ taglib prefix="base" uri="/WEB-INF/base.tld" %&gt;
  	&lt;base:help help_id="required_helpexternalID" /&gt;
  </pre>
  
  <p>
  <b>Syntax:</b>
  <pre>
  &lt;base:help
  	helpid=...
  	tabcontrol=...
  	clazz=...
  	style=...
  	image=...
  	tooltip=...
  	onclick=...
  	visible=...
  &gt;
  </pre>
  <p>
  	<table border=1 cellspacing=0 cellpadding=2>
  	<tr>
	  	<td><b>Attribute</b></td>
	  	<td><b>Default value</b></td>
	  	<td><b>Required</b></td>
	  	<td><b>Description</b></td>
  	</tr>
  	<tr>
  		<td>helpid</td>
  		<td></td>
  		<td>no</td>
  		<td>
  			The keyword of the help topic to display. Each help topic has a one-word key
  			to be identified with. If not specified then the <code>tabcontrol</code>
  			attribute must be specified. 			 
  		</td>
  	</tr>  	
  	<tr>
  		<td>tabcontrol</td>
  		<td></td>
  		<td>no</td>
  		<td>
  			The ID of the {@link net.sf.basedb.clients.web.taglib.tab.TabControl} to get the 
  			help id from. Each {@link net.sf.basedb.clients.web.taglib.tab.Tab} in a tabcontrol 
  			should specify it's own <code>helpid</code> attribute.
  		</td>
  	</tr>  	
  	<tr>
  		<td>clazz</td>
  		<td>help</td>
  		<td>no</td>
  		<td>
  			The value if this attribute goes directly into the standard HTML 
			<code>class</code> attribute. This allows you to apply different styles
			to different helps.  		
  		</td>
  	</tr>
  	<tr>
  		<td>style</td>
  		<td>-</td>
  		<td>no</td>
  		<td>
  			The value if this attribute goes directly into the standard HTML 
			<code>style</code> attribute. This allows you to apply different styles
			to different icons.
  		</td>
  	</tr>
  	<tr>
  		<td>image</td>
  		<td>-</td>
  		<td>no</td>
  		<td>
  			The name of the image to display. The image must be in the <code>/images</code>
			directory. Only include the filename, not the path.
			This taglib will find the correct path from the current jsp page.
		</td>
	</tr>
  	<tr>
  		<td>tooltip</td>
  		<td>-</td>
  		<td>no</td>
  		<td>
  			A short explanation that will show up as a tooltip.
  		</td>
  	</tr>
  	<tr>
  		<td>onclick</td>
  		<td>-</td>
  		<td>no</td>
  		<td>
  			An optional JavaScript statement that will exceute when the user
			clicks on the icon.
  		</td>
  	</tr>
  	<tr>
  		<td>visible</td>
  		<td>true</td>
  		<td>no</td>
  		<td>
  			If the help icon should be visible or not.
  		</td>
  	</tr>
  	
  	</table>
  	
  
  @author martin
  @version 2.0
*/
public class Help 
	extends TagSupport
{
	/**
		
	*/
	private static final long serialVersionUID = -2754197259139443681L;

	/**
	 	The parent &lt;base:page&gt; tag.	 	
	*/
	private Page page;
		
	/**
	 	The keyword of the helptopic
	*/
	private String helpid = null;
	
	/**
		The tabcontrol ID to get the help id from.
	*/
	private String tabcontrol = null;
	
	/**
 	Optional <code>class</code> attribute
	*/
	private String clazz = "help";
	
	/**
	 	Optional <code>style</code> attribute
	*/
	private String style = null;
	
	/**
	  	The path to the help icon
	*/
	private String image = "help.gif";
	
	/**
	 	Optional tooltip.
	*/
	private String tooltip = null;
	
	/**
	 	Optional JavaScript statement.
	*/
	private String onClick = null;
	
	/**
	 * 	If the help icon should be visible or not.
	 */
	private boolean visible = true;
	
	/*
	 	Taglib initialization methods
	*/
	public void setHelpid(String helpid)
	{
		this.helpid = helpid;
	}
	public String getHelpid()
	{
		return this.helpid;
	}
	
	public void setTabcontrol(String tabcontrol)
	{
		this.tabcontrol = tabcontrol;
	}
	public String getTabcontrol()
	{
		return this.tabcontrol;
	}
		
	public void setClazz(String clazz)
	{
		this.clazz = clazz;
	}
	public String getClazz()
	{
		return this.clazz;
	}
	
	public void setStyle(String style)
	{
		this.style = style;		
	}
	public String getStyle()
	{
		return this.style;
	}
	
	public void setImage(String image)
	{
		this.image = image;		
	}
	public String getImage()
	{
		return this.image;
	}
	
	public void setTooltip(String tooltip)
	{
		this.tooltip = tooltip;
	}
	public String getTooltip()
	{
		return this.tooltip;
	}
	
	public void setOnClick(String onclick)
	{
		this.onClick = onclick;
	}
	public String getOnClick()
	{
		return this.onClick;
	}
	
	public void setVisible(boolean visible)
	{
		this.visible = visible;
	}
	public boolean isVisible()
	{
		return this.visible;
	}
	
	public int doStartTag() 
		throws JspException
	{
		page = (Page)findAncestorWithClass(this, Page.class);
		if (page == null) throw new JspTagException("Tag <base:help > must be inside a <base:page> tag");
		if (!isVisible()) return SKIP_BODY;
		
		String theStyle = getStyle();
		
		if (getOnClick() != null)
		{
			theStyle = Values.getString(theStyle) + "cursor: pointer;";	
		}
		StringBuilder sb = new StringBuilder();
		sb.append("<a href=\"javascript:");
		if (getTabcontrol() != null)
		{
			sb.append("Main.openTabControlHelp('").append(pageContext.getRequest().getParameter("ID"));
			sb.append("', '").append(getTabcontrol()).append("', '").append(getHelpid()).append("')\">");
		}
		else
		{
			sb.append("Main.openHelp('").append(pageContext.getRequest().getParameter("ID"));
			sb.append("', '").append(getHelpid()).append("')\">");
		}
		sb.append("<img border=0");
		if (getClazz() != null) sb.append(" class=\"").append(getClazz()).append("\"");
		if (theStyle != null) sb.append(" style=\"").append(theStyle).append("\"");
		if (getTooltip() != null) sb.append(" title=\"").append(getTooltip()).append("\"");
		if (getOnClick() != null) sb.append(" onclick=\"").append(getOnClick()).append("\"");
		sb.append(" src=\"").append(page.getRoot()).append("images/").append(getImage()).append("\"");
		sb.append(">");
		sb.append("</a>");
		try
		{
			pageContext.getOut().print(sb.toString());
		}
		catch (Exception ex)
		{
			throw new JspTagException(ex.getMessage());
		}		
		return EVAL_BODY_INCLUDE;		
	}
}
