/*
	$Id: NameableUtil.java 4479 2008-09-05 15:16:27Z jari $

	Copyright (C) 2005 Jari Hakkinen, Nicklas Nordborg
	Copyright (C) 2006 Jari Hakkinen

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place - Suite 330,
	Boston, MA  02111-1307, USA.
*/
package net.sf.basedb.core;

import net.sf.basedb.core.data.NameableData;

/**
	Utility methods that will make it easier to implement
	the {@link Nameable} interface, including data validation.
	
	@author Nicklas
	@version 2.0
	@see Nameable
*/
public class NameableUtil
{

	/**
		Set the name of a {@link NameableData} object.
	 	@param nameableData A NameableData object to set a name on. 
	 	@param name The name to be set.
		@throws InvalidDataException If the name is null or is longer
			than {@link Nameable#MAX_NAME_LENGTH} constant
	*/
	public static void setName(NameableData nameableData, String name)
		throws InvalidDataException
	{
		nameableData.setName(
			StringUtil.setNotNullString(name, "name", Nameable.MAX_NAME_LENGTH)
		);
	}
	
	/**
		Set the description of a {@link NameableData} object. 
	 	@param nameableData A NameableData to set description on. 
	 	@param description The description to be set.
		@throws InvalidDataException If the description is longer
			than {@link Nameable#MAX_DESCRIPTION_LENGTH} constant
	*/
	public static void setDescription(NameableData nameableData, String description)
		throws InvalidDataException
	{
		nameableData.setDescription(
			StringUtil.setNullableString(description, "description", Nameable.MAX_DESCRIPTION_LENGTH)
		);
	}
}
