/**
	$Id: ParameterInfo.java 4479 2008-09-05 15:16:27Z jari $

	Copyright (C) 2006 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place - Suite 330,
	Boston, MA  02111-1307, USA.
*/
package net.sf.basedb.core;

import java.util.Collections;
import java.util.List;

import net.sf.basedb.core.data.ParameterValueData;

/**
	Get information about a plugin configuration or parameter. The information
	include the label, description and values of the parameter.

	@author nicklas
	@version 2.0
	@base.modified $Date: 2008-09-05 17:16:27 +0200 (Fri, 05 Sep 2008) $
*/
public class ParameterInfo
{
	private final String label;
	private final String description;
	private final List<?> values;

	ParameterInfo(DbControl dc, ParameterValueData parameter)
	{
		this.label = parameter.getLabel();
		this.description = parameter.getDescription();
		this.values = Collections.unmodifiableList(Values.getItemValues(dc, parameter.getValues()));
	}
	
	public String getLabel()
	{
		return label;
	}
	
	public String getDescription()
	{
		return description;
	}
	
	public List<?> getValues()
	{
		return values;
	}
	
}
