/**
	$Id: UnmodifiableResultList.java 4479 2008-09-05 15:16:27Z jari $

	Copyright (C) 2006 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or modify it
	under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 3 of the License, or
	(at your option) any later version.

	BASE is distributed in the hope that it will be useful, but
	WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
	General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
	02111-1307, USA. 
*/
package net.sf.basedb.core;

import net.sf.basedb.core.query.ResultList;

import java.util.ArrayList;
import java.util.Collection;
import java.util.List;

/**

	 @author nicklas
	 @version 2.0
	 @base.modified $Date: 2008-09-05 17:16:27 +0200 (Fri, 05 Sep 2008) $
*/
public class UnmodifiableResultList<T>
	extends ArrayList<T>
	implements ResultList<T>
{
	/**
		
	*/
	private static final long serialVersionUID = -1514212917126590560L;
	private final long totalCount;

	public UnmodifiableResultList(List<T> items, long totalCount)
	{
		super(items);
		this.totalCount = totalCount;
	}

	/*
		From the ResultList interface
		-------------------------------------------
	*/
	public long getTotalCount()
	{
		return totalCount;
	}
	// -------------------------------------------

	/*
		From the List interface
		-------------------------------------------
	*/
	/**
		Not supported.
		@throws UnsupportedOperationException Always
	*/
	public boolean add(T o)
	{
		throw new UnsupportedOperationException();
	}
	
	/**
		Not supported.
		@throws UnsupportedOperationException Always
	*/
	public void add(int index, T element)
	{
		throw new UnsupportedOperationException();
	}
	
	/**
		Not supported.
		@throws UnsupportedOperationException Always
	*/
	public boolean addAll(Collection<? extends T> c)
	{
		throw new UnsupportedOperationException();
	}
	
	/**
		Not supported.
		@throws UnsupportedOperationException Always
	*/
	public boolean addAll(int index, Collection<? extends T> c)
	{
		throw new UnsupportedOperationException();
	}
	
	/**
		Not supported.
		@throws UnsupportedOperationException Always
	*/
	public void clear()
	{
		throw new UnsupportedOperationException();
	}
	
	public boolean containsAll(Collection<?> c)
	{
		for (Object o : c)
		{
			if (!contains(o)) return false;
		}
		return true;
	}
	
	/**
		Not supported.
		@throws UnsupportedOperationException Always
	*/
	public T remove(int index)
	{
		throw new UnsupportedOperationException();
	}
	
	/**
		Not supported.
		@throws UnsupportedOperationException Always
	*/
	public boolean remove(Object o)
	{
		throw new UnsupportedOperationException();
	}
	
	/**
		Not supported.
		@throws UnsupportedOperationException Always
	*/
	public boolean removeAll(Collection<?> c)
	{
		throw new UnsupportedOperationException();
	}
	
	/**
		Not supported.
		@throws UnsupportedOperationException Always
	*/
	public boolean retainAll(Collection<?> c)
	{
		throw new UnsupportedOperationException();
	}
	
	/**
		Not supported.
		@throws UnsupportedOperationException Always
	*/
	public T set(int index, T element)
	{
		throw new UnsupportedOperationException();
	}
	// -------------------------------------------


}
