/*
	$Id: DataCubeData.java 4479 2008-09-05 15:16:27Z jari $
	
	Copyright (C) 2005 Nicklas Nordborg
	Copyright (C) 2006 Jari Hakkinen, Nicklas Nordborg
	
	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/
	
	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.
	
	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place - Suite 330,
	Boston, MA  02111-1307, USA.
*/
package net.sf.basedb.core.data;

import java.util.Set;

/**
	This class holds information about a single data cube in a virtual database.
	
	@author Nicklas
	@version 2.0
	@see net.sf.basedb.core.DataCube
	@see <a href="../../../../../../html/developerdoc/api/data_api.experiments.html">Experiments and analysis overview</a>
	@base.modified $Date: 2008-09-05 17:16:27 +0200 (Fri, 05 Sep 2008) $
	@hibernate.class table="`DataCubes`" lazy="true"
*/
public class DataCubeData
	extends BasicData
{
	public DataCubeData()
	{}

	private VirtualDbData virtualDb;
	/**
		Get the virtual database this cube belongs to.
		@hibernate.many-to-one column="`virtualdb_id`" not-null="true" outer-join="false" update="false" unique-key="uniquecube"
	*/
	public VirtualDbData getVirtualDb()
	{
		return virtualDb;
	}
	public void setVirtualDb(VirtualDbData virtualDb)
	{
		this.virtualDb = virtualDb;
	}

	private short cubeNo;
	/**
		The cube number of this cube in the virtual database.
		@hibernate.property column="`cube_no`" type="short" not-null="true" update="false" unique-key="uniquecube"
	*/
	public short getCubeNo()
	{
		return cubeNo;
	}
	public void setCubeNo(short cubeNo)
	{
		this.cubeNo = cubeNo;
	}
	
	private long bytes;
	/**
		The number of bytes the analysed data in this cube occupies on disk.
		Updates to this column are done through SQL statements and not
		through this object.
		@hibernate.property column="`bytes`" type="long" not-null="true" update="false"
	*/
	public long getBytes()
	{
		return bytes;
	}
	public void setBytes(long bytes)
	{
		this.bytes = bytes;
	}

	private short numFilters;
	/**
		The number of filters in this data cube. Updates
		to this column are done through SQL statements and not
		through this object.
		@hibernate.property column="`filters`" type="short" not-null="true" update="false"
	*/
	public short getNumFilters()
	{
		return numFilters;
	}
	public void setNumFilters(short numFilters)
	{
		this.numFilters = numFilters;
	}
	
	private short numExtraValues;
	/**
		The number of extra values in this data cube. Updates
		to this column are done through SQL statements and not
		through this object.
		@hibernate.property column="`extravalues`" type="short" not-null="true" update="false"
	*/
	public short getNumExtraValues()
	{
		return numExtraValues;
	}
	public void setNumExtraValues(short numExtraValues)
	{
		this.numExtraValues = numExtraValues;
	}

	private short numLayers;
	/**
		The number of layers in this data cube. Updates
		to this column are done through SQL statements and not
		through this object.
		@hibernate.property column="`layers`" type="short" not-null="true" update="false"
	*/
	public short getNumLayers()
	{
		return numLayers;
	}
	public void setNumLayers(short numLayers)
	{
		this.numLayers = numLayers;
	}

	private short numColumns;
	/**
		The number of columns in this data cube.
		@hibernate.property column="`columns`" type="short" not-null="true" update="false"
	*/
	public short getNumColumns()
	{
		return numColumns;
	}
	public void setNumColumns(short numColumns)
	{
		this.numColumns = numColumns;
	}

	private int numPositions;
	/**
		The number of positions in this data cube.
		@hibernate.property column="`positions`" type="int" not-null="true" update="false"
	*/
	public int getNumPositions()
	{
		return numPositions;
	}
	public void setNumPositions(int numPositions)
	{
		this.numPositions = numPositions;
	}
	
	private int maxRawMappings;
	/**
		The maximum number of raw data spots a single spot in this data cube
		is mapped to.
		@hibernate.property column="`max_raw_spots`" type="int" not-null="true" update="false"
	*/
	public int getMaxRawMappingsForSpot()
	{
		return maxRawMappings;
	}
	public void setMaxRawMappingsForSpot(int maxRawMappings)
	{
		this.maxRawMappings = maxRawMappings;
	}

	private Set<DataCubeLayerData> layers;
	/**
		This is the inverse end.
		@see DataCubeLayerData#getDataCube()
		@hibernate.set lazy="true" inverse="true" cascade="delete"
		@hibernate.collection-key column="`datacube_id`"
		@hibernate.collection-one-to-many class="net.sf.basedb.core.data.DataCubeLayerData"
	*/
	Set<DataCubeLayerData> getLayers()
	{
		return layers;
	}
	void setLayers(Set<DataCubeLayerData> layers)
	{
		this.layers = layers;
	}

	private Set<DataCubeColumnData> columns;
	/**
		This is the inverse end.
		@see DataCubeColumnData#getDataCube()
		@hibernate.set lazy="true" inverse="true" cascade="delete"
		@hibernate.collection-key column="`datacube_id`"
		@hibernate.collection-one-to-many class="net.sf.basedb.core.data.DataCubeColumnData"
	*/
	Set<DataCubeColumnData> getColumns()
	{
		return columns;
	}
	void setColumns(Set<DataCubeColumnData> columns)
	{
		this.columns = columns;
	}

	private Set<DataCubeFilterData> filters;
	/**
		This is the inverse end.
		@see DataCubeFilterData#getDataCube()
		@hibernate.set lazy="true" inverse="true" cascade="delete"
		@hibernate.collection-key column="`datacube_id`"
		@hibernate.collection-one-to-many class="net.sf.basedb.core.data.DataCubeFilterData"
	*/
	Set<DataCubeFilterData> getFilters()
	{
		return filters;
	}
	void setFilters(Set<DataCubeFilterData> filters)
	{
		this.filters = filters;
	}

	private Set<DataCubeExtraValueData> extraValues;
	/**
		This is the inverse end.
		@see DataCubeExtraValueData#getDataCube()
		@hibernate.set lazy="true" inverse="true" cascade="delete"
		@hibernate.collection-key column="`datacube_id`"
		@hibernate.collection-one-to-many class="net.sf.basedb.core.data.DataCubeExtraValueData"
	*/
	Set<DataCubeExtraValueData> getExtraValues()
	{
		return extraValues;
	}
	void setExtraValues(Set<DataCubeExtraValueData> extraValues)
	{
		this.extraValues = extraValues;
	}
	
}
