/*
	$Id: UsedQuantity.java 4479 2008-09-05 15:16:27Z jari $

	Copyright (C) 2005 Nicklas Nordborg
	Copyright (C) 2006 Jari Hakkinen, Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place - Suite 330,
	Boston, MA  02111-1307, USA.
*/
package net.sf.basedb.core.data;

import java.io.Serializable;

/**
	Hibernate will not save entries in the sources map {@link BioMaterialEventData#getSources()}
	where the element is null, so we have to use a composite element instead. This class
	maps the <code>used_quantity</code> column in the <code>BioMaterialEventSources<code> table.
	<p>
	NOTE! In 2.6 we changed the 'dummy' property to {@link #getSourceGroup()}
	to be able to solve the problem with multi-array hybridizations. The name
	of this class is now a bit misleading but we see no real reason to rename
	it since it is part of the internal API only.
	<p>
	NOTE! The inverse relation is mapped in {@link MeasuredBioMaterialData#getSourceEvents()}
	and uses the {@link BioMaterialSourceEventData} class to hold the same columns
	as this class.
	
	@author Nicklas
	@version 2.0
	@see <a href="../../../../../../html/developerdoc/api/data_api.biomaterials.html">Biomaterials overview</a>
	@base.modified $Date: 2008-09-05 17:16:27 +0200 (Fri, 05 Sep 2008) $
*/
public class UsedQuantity
	implements Serializable
{

	/**
		
	*/
	private static final long serialVersionUID = -2938528453996490494L;
	/**
		The used quantity value.
	*/
	private Float usedQuantity = null;

	/**
		Used by Hibernate to create an instance.
	*/
	UsedQuantity()
	{}

	/**
		Create a new instance.
		@param usedQuantity The used quantity
	*/
	public UsedQuantity(Float usedQuantity, int sourceGroup)
	{
		this.usedQuantity = usedQuantity;
		this.sourceGroup = sourceGroup;
	}

	/**
		Get the used quantity.
		@hibernate.property column="`used_quantity`" not-null="false" type="float"
	*/
	public Float getUsedQuantity()
	{
		return usedQuantity;
	}
	public void setUsedQuantity(Float usedQuantity)
	{
		this.usedQuantity = usedQuantity;
	}
	
	private int sourceGroup;
	/**
		This column was previously used as a 'dummy' value for making
		sure that links were not deleted when the used quantity was
		null. From 2.6 this column is used to group sources together.
		This is needed to support multi-array hybridizations where we
		need to know the array each labeled extract goes into. 
		@hibernate.property column="`dummy`" type="int" not-null="true"
		@since 2.6
	*/
	public int getSourceGroup()
	{
		return sourceGroup;
	}
	public void setSourceGroup(int sourceGroup)
	{
		this.sourceGroup = sourceGroup;
	}

	/**
		Convert the value to a string.
	*/
	public String toString()
	{
		return usedQuantity == null ? "null" : usedQuantity.toString();
	}

}

