/**
	$Id: ImmediateDownloadExporter.java 4479 2008-09-05 15:16:27Z jari $

	Copyright (C) 2006 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place - Suite 330,
	Boston, MA  02111-1307, USA.
*/
package net.sf.basedb.core.plugin;

import java.io.IOException;

import net.sf.basedb.core.Job;
import net.sf.basedb.core.ProgressReporter;

/**
	This interface should be implemented by export plugins
	that supports immediate download to the client application.
	<p>
	The plugin will be loaded and initialised normally and a
	job configuration sequence is started by a call to 
	{@link InteractivePlugin#configure(GuiContext, Request, Response)}.
	When the configuration is complete the plugin may respond with 
	a {@link Response#setDownloadImmediately(String, Job.ExecutionTime, boolean)} 
	instead of a {@link Response#setDone(String, Job.ExecutionTime)}. This will prevent the
	core from saving a job in the job queue. Instead it will call the
	{@link #doExport(ExportOutputStream, ProgressReporter)} method to let the plugin
	generate it's output. The {@link Plugin#run(Request, Response, ProgressReporter)}
	method is never called.
	<p>
	Note that this feature requires that the plugin is executed in the same
	virtual machine and prevents the use of job agents. Plugins should not use
	immediate export if they use a lot of memory, requires long running times or
	consumes other resources that may cause problems for other code.
	
	@author Nicklas
	@version 2.2
	@base.modified $Date: 2008-09-05 17:16:27 +0200 (Fri, 05 Sep 2008) $
*/
public interface ImmediateDownloadExporter
	extends Plugin
{

	/**
		Perform the export.

		@param out The output stream that the exported data should be written to
		@param progress An optional progress reporter, may be null
		@throws IOException If there is an error writing to the export stream
	*/
	public void doExport(ExportOutputStream out, ProgressReporter progress)
		throws IOException;
	
}
