/*
	$Id: EntityQuery.java 4479 2008-09-05 15:16:27Z jari $

	Copyright (C) 2005 Nicklas Nordborg
	Copyright (C) 2006 Jari Hakkinen, Nicklas Nordborg, Martin Svensson
	Copyright (C) 2007 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place - Suite 330,
	Boston, MA  02111-1307, USA.
*/
package net.sf.basedb.core.query;

import java.util.Collection;

import net.sf.basedb.core.Item;
import net.sf.basedb.core.Include;
import net.sf.basedb.core.Permission;

/**
	This a HQL query that return enitities, ie. items. The items may be returned
	in the form of data classes ({@link net.sf.basedb.core.DataQuery}) or
	in the form of item classes ({@link net.sf.basedb.core.ItemQuery}).
	
	@author Nicklas
	@version 2.0
	@base.modified $Date: 2008-09-05 17:16:27 +0200 (Fri, 05 Sep 2008) $
*/
public interface EntityQuery
	extends HqlQuery
{

	/**
		The type of items the query returns.
	*/
	public Item getItemType();
	
	/**
		The type of items that is the root of the query. In most cases,
		this is the same as the {@link #getItemType()}, but not
		always.
		@since 2.8
	*/
	public Item getRootType();
	
	/**
		Specify options for which items to include in the result. 

		@base.developer
		These options are implemented as Hibernate filters. See
		{@link net.sf.basedb.core.QueryRuntimeFilterFactory}
		
		@param includes An array of items that should be included
		@throws UnsupportedOperationException If this operation isn't supported by
			the implementation
		@see #exclude(Include[])
	*/
	public void include(Include... includes);
	
	/**
		@see #include(Include[])
	*/
	public void include(Collection<Include> includes);
	
	/**
		Specify options for which items to exclude from the result. 

		@base.developer
		These options are implemented as Hibernate filters. See
		{@link net.sf.basedb.core.QueryRuntimeFilterFactory}
		
		@param excludes An array of options that should be excluded
		@throws UnsupportedOperationException If this operation isn't supported by
			the implementation
		@see #include(Include[])
	*/
	public void exclude(Include... excludes);
	
	/**
		@see #exclude(Include[])
	*/
	public void exclude(Collection<Include> excludes);
	
	/**
		Check which options are set for the items to include in the result
		@param includes The options to check
		@return TRUE If all specified options are included, FALSE otherwise
	*/
	public boolean isIncluded(Include... includes);
	
	/**
		@see #isIncluded(Include[])
	*/
	public boolean isIncluded(Collection<Include> includes);
	
	/**
		Only return items which the logged in user has the specified 
		permission for. The default is to return all items which the user 
		has at least read permission for. 
		@param permission The required permission
	*/
	public void setItemPermission(Permission permission);
	

	/**
	 	The logged in user's permission on the items returned by this query.
		@return A Permission object
	*/
	public Permission getItemPermission();
}
