/*
	$Id: HqlPropertyExpression.java 4479 2008-09-05 15:16:27Z jari $

	Copyright (C) 2005 Nicklas Nordborg
	Copyright (C) 2006 Jari Hakkinen, Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place - Suite 330,
	Boston, MA  02111-1307, USA.
*/
package net.sf.basedb.core.query;

import java.util.Collection;

import net.sf.basedb.core.DbControl;
import net.sf.basedb.core.BaseException;

/**
	An expression representing the property of a
	Hibernate entity: alias.property.
	<p>
	Throws an <code>UnsupportedOperationException</code> if 
	{@link Query#getQueryType()} isn't {@link QueryType#HQL}.

	@author Nicklas
	@version 2.0
	@see Hql#property(String, String)
	@base.modified $Date: 2008-09-05 17:16:27 +0200 (Fri, 05 Sep 2008) $
*/
public class HqlPropertyExpression
	implements Expression
{
	private final String alias;
	private final String property;

	HqlPropertyExpression(String alias, String property)
	{
		this.alias = alias;
		this.property = property;
	}

	/*
		From the QueryElement interface
		-------------------------------------------
	*/
	public String toQl(Query query, DbControl dc)
		throws BaseException
	{
		if (query.getQueryType() == QueryType.HQL)
		{
			return (alias == null ? query.getRootAlias() : alias) + (property == null ? "" : "." +property);
		}
		else
		{
			throw new UnsupportedOperationException("'property' operation not supported by "+query.getQueryType()+" query.");
		}
	}
	/**
		@return Always null
	*/
	public Collection<? extends QueryElement> getChildren()
	{
		return null;
	}
	// -------------------------------------------
	/*
		From the Object class
		-------------------------------------------
	*/
	public String toString()
	{
		return (alias == null ? "" : alias + ".") + property;
	}
	// -------------------------------------------
}
