/**
	$Id: SignalReceivedException.java 4479 2008-09-05 15:16:27Z jari $

	Copyright (C) Authors contributing to this file.

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place - Suite 330,
	Boston, MA  02111-1307, USA.
*/
package net.sf.basedb.core.signal;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

/**
	This exception can be thrown by signal handlers when one or more
	signal has been received.
	
	@author nicklas
	@version 2.6
	@base.modified $Date: 2008-09-05 17:16:27 +0200 (Fri, 05 Sep 2008) $
*/
public class SignalReceivedException
	extends SignalException
{
	
	/**
		
	*/
	private static final long serialVersionUID = -1498169053139644792L;
	private List<Signal> signals;
	
	/**
		Create a new UnsupportedSignalException.
		@param signal The signal that is not supported
	*/
	public SignalReceivedException(Signal signal)
	{
		this(Arrays.asList(signal));
	}
	
	/**
		Create a new SignalReceivedException when multiple signals has
		been received.
		@param signals The signals in the order they were received
	*/
	public SignalReceivedException(Signal... signals)
	{
		this(Arrays.asList(signals));
	}

	/**
		Create a new SignalReceivedException when multiple signals has
		been received.
		@param signals The signals in the order they were received
	*/
	public SignalReceivedException(List<Signal> signals)
	{
		super("Signals received: " + signals);
		this.signals = new ArrayList<Signal>(signals);
	}
	
	/**
		Get the signals that has been received.
		@return A list with the signals in the order they were received
	*/
	public List<Signal> getSignals()
	{
		return signals;
	}
	
}
