/**
	$Id: FileExportOutputStream.java 4479 2008-09-05 15:16:27Z jari $

	Copyright (C) 2006 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place - Suite 330,
	Boston, MA  02111-1307, USA.
*/
package net.sf.basedb.util;

import net.sf.basedb.core.File;
import net.sf.basedb.core.plugin.ExportOutputStream;

/**
 	An extension to the {@link ExportOutputStream} class which 
 	directs the output to a {@link File} in BASE.

	@author nicklas
	@version 2.2
	@base.modified $Date: 2008-09-05 17:16:27 +0200 (Fri, 05 Sep 2008) $
	@see net.sf.basedb.core.plugin.ImmediateDownloadExporter
*/
public class FileExportOutputStream
	extends ExportOutputStream
{
	private final File file;
	private final boolean ignoreFilename;

	/**
		Create a new export stream that writes the exported data to 
		a file in the BASE filesystem
		@param file The file to write to
		@param ignoreFilename If calls to the {@link #setFilename(String)}
			should be ignored or not
	*/
	public FileExportOutputStream(File file, boolean ignoreFilename)
	{
		super(file.getUploadStream(false));
		this.file = file;
		this.ignoreFilename = ignoreFilename;
	}
	
	/*
	 	From the ExportOutputStream class
	 	---------------------------------
	*/
	/**
		Ignored. File size is calculated from the number of bytes written 
		to the file.
	*/
	@Override
	public void setContentLength(long contentLength)
	{}
	/**
		Calls {@link File#setMimeType(String)}
	*/
	@Override
	public void setMimeType(String mimeType)
	{
		file.setMimeType(mimeType);
	}
	/**
		Calls {@link File#setName(String)} unless file names should
		be ignored.
	*/
	@Override
	public void setFilename(String filename)
	{
		if (!ignoreFilename) file.setName(filename);
	}
	// -------------------------------------------
}
