/**
	$Id: ErrorHandler.java 4479 2008-09-05 15:16:27Z jari $

	Copyright (C) 2006 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place - Suite 330,
	Boston, MA  02111-1307, USA.
*/
package net.sf.basedb.util.error;

/**
 	An interface to make it easier to implement dynamic error handling. 
 	A typical implementation allows the registration of one or more error
 	handlers. When an exception is thrown the {@link #handleError(Throwable)}
 	method is invoked on the first error handler. There are three outcomes:
 	<ul>
 	<li>The error handler has decided that the error is unrecoverable and
 		re-throws the same (or another) exception.
 	<li>The error handler could handle the error and returns TRUE to indicate
 		that processing should continue. No more error handlers should be invoked.
 	<li>The error handler doesn't know what to do and returns FALSE. The next error
 		handler should be invoked and if no more are available the exception
 		should be rethrown.
 	</ul>

	@author nicklas
	@version 2.0
	@base.modified $Date: 2008-09-05 17:16:27 +0200 (Fri, 05 Sep 2008) $
*/
public interface ErrorHandler
{

	/**
		Handle an error. If it is decided that the error is a final error
		this method should rethrow the same or a different exception. If
		if is decided that it is possible to continue with the current operation
		<code>true</code> should be returned. If <code>false</code> is returned
		it indicates that this error handled doesn't know how to handle the 
		error. The caller should try another error handler or throw an exception.
		
		@param t The error to handle
		@return TRUE if the error was handled successfully and the execution should
			continue with the next item
		@throws Throwable If the error is final and can't be solved
	*/
	public boolean handleError(Throwable t)
		throws Throwable;
	
}
