/**
	$Id: SimpleErrorHandler.java 4479 2008-09-05 15:16:27Z jari $

	Copyright (C) 2006 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place - Suite 330,
	Boston, MA  02111-1307, USA.
*/
package net.sf.basedb.util.error;

/**
 	A simple error handler that either ignores all errors or
 	re-throws them.
 	
	@author nicklas
	@version 2.0
	@base.modified $Date: 2008-09-05 17:16:27 +0200 (Fri, 05 Sep 2008) $
*/
public class SimpleErrorHandler
	implements ErrorHandler
{

	private final boolean ignoreAllErrors;
	
	/**
		Create a new simple error handler.
		@param ignoreAllErrors TRUE to ignore all errors, FALSE to re-throw them
	*/
	public SimpleErrorHandler(boolean ignoreAllErrors)
	{
		this.ignoreAllErrors = ignoreAllErrors;
	}
	
	/*
		From the ErrorHandler interface
		-------------------------------------------
	*/
	/**
		Return TRUE if all errors should be ignored, otherwise re-throw the
		throwable.
	*/
	public boolean handleError(Throwable t) 
		throws Throwable
	{
		if (ignoreAllErrors) return true;
		throw t;
	}
	// -------------------------------------------

}
