/**
	$Id: DefaultFilter.java 4479 2008-09-05 15:16:27Z jari $

	Copyright (C) Authors contributing to this file.

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place - Suite 330,
	Boston, MA  02111-1307, USA.
*/
package net.sf.basedb.util.extensions;

import java.util.Collections;
import java.util.Comparator;
import java.util.List;

/**
	A default filter implementation that enables all
	extensions and extension points and sorts the
	extensions based on the {@link Extension#getIndex()}
	values.
	
	@author nicklas
	@version 2.7
	@base.modified $Date:2008-03-20 12:15:25 +0100 (Thu, 20 Mar 2008) $
*/
public class DefaultFilter 
	implements ExtensionsFilter 
{

	/**
		Comparator used to order a list of invokation contexts by 
		the index value of the extension.
		@see Extension#getIndex()
	*/
	public static final Comparator<InvokationContext<?>> INDEX_COMPARATOR_CTX = 
		new Comparator<InvokationContext<?>>()
		{
			@Override
			public int compare(InvokationContext<?> o1, InvokationContext<?> o2) 
			{
				return Float.compare(o1.getExtension().getIndex(), o2.getExtension().getIndex());
			}
		};

	/**
		Comparator used to order a list of extensions by 
		the index value of the extension.
		@see Extension#getIndex()
	*/
	public static final Comparator<Extension<?>> INDEX_COMPARATOR_EXT = 
		new Comparator<Extension<?>>()
		{
			@Override
			public int compare(Extension<?> o1, Extension<?> o2) 
			{
				return Float.compare(o1.getIndex(), o2.getIndex());
			}
		};
		
	/**
		Create a new default filter.
	*/
	public DefaultFilter()
	{}
	
	/*
		From the ExtensionsFilter interface
		-----------------------------------
	*/
	@Override
	public boolean isEnabled(ExtensionPoint<?> extensionPoint) 
	{
		return true;
	}

	@Override
	public boolean isEnabled(Extension<?> extension) 
	{
		return true;
	}

	@Override
	public void sort(List<? extends InvokationContext<?>> extensions) 
	{
		Collections.sort(extensions, INDEX_COMPARATOR_CTX);
	}
	// --------------------------------------------------
}
