/**
	$Id: SingleExtensionFilter.java 4479 2008-09-05 15:16:27Z jari $

	Copyright (C) Authors contributing to this file.

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place - Suite 330,
	Boston, MA  02111-1307, USA.
*/
package net.sf.basedb.util.extensions;

import java.util.List;

/**
	A filter implementation that enables a single extension and
	disables all other.
	
	@author nicklas
	@version 2.8
	@base.modified $Date:2008-03-20 12:15:25 +0100 (Thu, 20 Mar 2008) $
*/
public class SingleExtensionFilter 
	implements ExtensionsFilter 
{

	private final String id;
	
	/**
		Create a filter that enables the given extension 
		and disables all other.
	*/
	public SingleExtensionFilter(Extension extension)
	{
		this.id = extension.getId();
	}
	
	/**
		Create a filter that enables the extension with the 
		given ID and disables all others.
	*/
	public SingleExtensionFilter(String id)
	{
		this.id = id;
	}
	
	/*
		From the ExtensionsFilter interface
		-----------------------------------
	*/
	@Override
	public boolean isEnabled(ExtensionPoint<?> extensionPoint) 
	{
		return true;
	}

	@Override
	public boolean isEnabled(Extension<?> extension) 
	{
		return extension.getId().equals(id);
	}

	/**
		Do nothing since the list should contain only a single extension.
	*/
	@Override
	public void sort(List<? extends InvokationContext<?>> extensions) 
	{}
	// --------------------------------------------------
}
