/**
$Id: Bzip2FilePacker.java 4479 2008-09-05 15:16:27Z jari $

Copyright (C) 2007 Nicklas Nordborg

This file is part of BASE - BioArray Software Environment.
Available at http://base.thep.lu.se/

BASE is free software; you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 3 of the License, or
(at your option) any later version.

BASE is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
02111-1307, USA.
*/

package net.sf.basedb.util.zip;

import java.io.IOException;
import java.io.OutputStream;
import java.util.zip.GZIPOutputStream;

import org.apache.tools.bzip2.CBZip2OutputStream;

/**
 	This class wraps the {@link TarFilePacker} in a BZIP2 stream, creating
 	a tar.bz2 file.

  	@author martin, Nicklas
  	@version 2.4
  	@base.modified $Date: 2008-09-05 17:16:27 +0200 (Fri, 05 Sep 2008) $  	
*/
public class Bzip2FilePacker 
	extends TarFilePacker
{

	private CBZip2OutputStream bzip;
	
	/**
		Create a new packer that compresses files with the BZIP2 format.
	*/
	public Bzip2FilePacker()
	{}
	
	/*
		From the FilePacker interface
		-------------------------------------------
	*/
	/**
		@return "BZipped TAR-archive (.tar.bz2)"
	*/
	public String getDescription()
	{
		return "BZipped TAR-archive (.tar.bz2)";
	}
	/**
	  @return "tar.bz2"
	*/
	public String getFileExtension()
	{
		return "tar.bz2";
	}
	/**
	  @return "application/x-bzip2"
	*/
	public String getMimeType()
	{
		return "application/x-bzip2";
	}
	/**
		Wrap the output stream in a {@link GZIPOutputStream}.
	*/
	public void setOutputStream(OutputStream out)
		throws IOException
	{
		out.write('B');
		out.write('Z');
		this.bzip = new CBZip2OutputStream(out);
		super.setOutputStream(bzip);
	}
	/**
		Finish the BZIP stream.
	*/
	public void close()
		throws IOException
	{
		super.close();
		bzip = null;
	}
	// -------------------------------------------

}
