/**
	$Id: ZipFileUnpacker.java 4480 2008-09-05 15:16:58Z jari $

	Copyright (C) 2006 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place - Suite 330,
	Boston, MA  02111-1307, USA.
*/
package net.sf.basedb.plugins;

import java.io.IOException;
import java.io.InputStream;
import java.util.Arrays;
import java.util.LinkedHashSet;
import java.util.Set;
import java.util.zip.ZipInputStream;

import net.sf.basedb.core.AbsoluteProgressReporter;
import net.sf.basedb.core.DbControl;
import net.sf.basedb.core.Directory;
import net.sf.basedb.core.Version;
import net.sf.basedb.core.plugin.About;
import net.sf.basedb.core.plugin.AboutImpl;
import net.sf.basedb.util.zip.AbstractFileUnpacker;
import net.sf.basedb.util.zip.ZipUnpacker;

/**
	A plugin for unpacking zip and jar file on the BASE file system.
	
	@author nicklas
	@version 2.0
	@base.modified $Date: 2008-09-05 17:16:58 +0200 (Fri, 05 Sep 2008) $
*/
public class ZipFileUnpacker
	extends AbstractFileUnpacker
{
	
	/**
	   Plugin description
	*/
	private static final About about = 
		new AboutImpl
		(
			"ZIP file unpacker",
			"This plugin unpacks a zip file on the BASE file system. It supports zip and jar files.", 
			Version.getMajor() + "." + Version.getMinor() + "." + Version.getMaintenance(),
			"2006, Base 2 development team",
			null,
			null,
			"http://base.thep.lu.se"
		);

	private static final Set<String> extensions =  
		new LinkedHashSet<String>(Arrays.asList("zip", "jar"));

	private static final Set<String> mimeTypes =  
		new LinkedHashSet<String>(Arrays.asList("application/zip", "application/java-archive"));

	/*
		From the Plugin interface
		-------------------------------------------
	*/
	public About getAbout()
	{
		return about;
	}
	// -------------------------------------------
	
	/*
		From the FileUnpacker interface
		-------------------------------------------
	*/
	public String getFormatName()
	{
		return "Zip files";
	}
	/**
		Return a set containing the strings [ zip, jar ].
	*/
	public Set<String> getExtensions()
	{
		return extensions;
	}
	/**
		Return a set containing the strings [ application/zip, application/java-archive ].
	*/
	public Set<String> getMimeTypes()
	{
		return mimeTypes;
	}
	/**
		Use the {@link ZipUnpacker} to unpack the file.
	*/
	public int unpack(DbControl dc, Directory dir, InputStream in,
		boolean overwrite, AbsoluteProgressReporter progress)
		throws IOException
	{
		ZipUnpacker unpacker = new ZipUnpacker(dc);
		ZipInputStream zipStream = new ZipInputStream(in);
		return unpacker.unpackZipFile(dir, zipStream, overwrite, progress);
	}
	// -------------------------------------------

}
