/**
	$Id: TestExternalPluginInstaller.java 4480 2008-09-05 15:16:58Z jari $
	
	Copyright (C) 2007 Nicklas Nordborg
	
	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/
	
	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.
	
	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place - Suite 330,
	Boston, MA  02111-1307, USA.
*/

import net.sf.basedb.util.FileUtil;
import net.sf.basedb.util.PluginConfigInfo;
import net.sf.basedb.util.PluginInfo;
import net.sf.basedb.util.RegexpFileFilter;

import java.io.File;
import java.io.FileFilter;
import java.util.ArrayList;
import java.util.List;

public class TestExternalPluginInstaller
{
	private static boolean ok = true;
	
	public static void main(String args[])
	{
		TestUtil.checkArgs(args);
		TestUtil.begin();
		ok = test_all();
		TestUtil.stop();
	}
	
	static boolean test_all()
	{		
		write("++Testing External plugin installer");
		List<File> jars = test_findPluginJars();
		List<PluginInfo> classInfos = test_loadFromJar(jars);
		test_installPlugins(classInfos);
		write("++Testing External plugin installer "+(ok ? "OK" : "Failed")+"\n");
		return ok;
	}
	
	/**
	 	Test to find jar-files in directory specified in plugins.dir
	  	@return List with files
	 */
	static List<File>test_findPluginJars()
	{
		File pluginDir = new File(".");
		FileFilter filter = new RegexpFileFilter(".*\\.jar", null);
		List<File> jarFiles = FileUtil.findFiles(pluginDir, filter);
		if (jarFiles != null)
		{
			write("--Number of jar-files that were found: " + jarFiles.size());
		}
		return jarFiles;
	}
	
	/**
	 	Test to load information for each plugin in plugin-jar files.
	  	@param jars A list with jar files that should be loaded
	  	@return List with PluginInfo objects
	 */
	static List<PluginInfo> test_loadFromJar(List<File> jars)
	{
		List<PluginInfo> info = new ArrayList<PluginInfo>();
		if (jars != null && !jars.isEmpty())
		{
			for (File jarFile : jars)
			{
				try
				{
					info.addAll(PluginInfo.loadFromJar(jarFile));
				} 
				catch (Throwable ex)
				{
					write("--Load classes from jar file: " + jarFile + " FAILED");
					ex.printStackTrace();
					ok = false;
				}
			}
			write("--Number of plugin-classes found in jar-file: " + info.size());
		}
		else
		{
			write("--No jar-files to load from");
			ok = false;
		}
		return info;
	}
	
	/**
	 	Test to install plugins in jar-file by using PluginInfo objects.
	 	The plugins will be removed again before leaving this method and 
	 	a few lines are printed to prompt.
	  	@param infos A list with PluginInfo objects, 
	  		one for each plugin that should be installed.
	 */
	static void test_installPlugins(List<PluginInfo> infos)
	{
		List<Integer> pluginIds = new ArrayList<Integer>();		
		List<PluginInfo> notInstalled = new ArrayList<PluginInfo>();
		for (PluginInfo info : infos)
		{
			int pluginid = TestPluginDefinition.test_create(info.getClassName(), info.getJarPath());
			try 
			{
				if (pluginid > 0)
				{					
					List<PluginConfigInfo> configurations = info.getConfigurations();
					if (configurations != null && configurations.size() > 0)
					{
						write("--Configurations for this plugin that were found: " + configurations.size());
					}
					else
					{
						write ("--No configurations were found for this plugin");
					}
					pluginIds.add(pluginid);
				}
				else
				{
					notInstalled.add(info);
				}
			}
			catch(Throwable th)
			{
				th.printStackTrace();
				if (pluginid > 0)
				{
					TestPluginDefinition.test_delete(pluginid);
				}
			}
		}
		write("--Number of plugins that could be installed " + pluginIds.size() + " of " + infos.size());
		if (!notInstalled.isEmpty())
		{
			write("---Following plugins classes couldn't be installed:\n ");
			for (PluginInfo pinfo : notInstalled)
			{
				write("\t" + pinfo.getClassName());
			}
		}
		for (int i : pluginIds)
		{
			TestPluginDefinition.test_delete(i);
		}
	}
	
	static void write(String message)
	{
		System.out.println(message);
	}
}
