import java.util.Date;

import net.sf.basedb.core.BaseException;
import net.sf.basedb.core.DbControl;
import net.sf.basedb.core.Hardware;
import net.sf.basedb.core.HardwareType;
import net.sf.basedb.core.Item;
import net.sf.basedb.core.Permission;
import net.sf.basedb.core.ItemResultList;
import net.sf.basedb.core.SystemItems;

/*
 $Id$

	Copyright (C) 2005 Johan Enell, Nicklas Nordborg
	Copyright (C) 2006 Jari Hakkinen

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

 BASE is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation; either version 3
 of the License, or (at your option) any later version.

 BASE is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place - Suite 330,
 Boston, MA  02111-1307, USA.
 */

public class TestHardware
{
	static boolean ok = true;

	public static void main(String[] args)
	{
		TestUtil.checkArgs(args);
		TestUtil.begin();
		ok = test_all();
		TestUtil.stop();
	}

	static boolean test_all()
	{
		write("++Testing hardware");
		write_header();
		// Standard tests: create, load, list
		int id = test_create(SystemItems.getId(HardwareType.SCANNER), null, true);
		int id2 = test_create(SystemItems.getId(HardwareType.SCANNER), null, false);
		test_load(id);
		test_list();

		// Extra tests:
		if (TestUtil.waitBeforeDelete()) TestUtil.waitForEnter();

		// Standard test: Delete
		test_delete(id);
		test_delete(id2);
		write("++Testing hardware "+(ok ? "OK" : "Failed")+"\n");
		return ok;
	}

	static int test_create(int hardwaretypeId, String name, boolean setAll)
	{
		if (hardwaretypeId == 0 || !TestUtil.hasPermission(Permission.CREATE, Item.HARDWARE)) return 0;
		int id = 0;
		DbControl dc = null;
		try
		{
			dc = TestUtil.getDbControl();
			HardwareType ht = HardwareType.getById(dc, hardwaretypeId);
			Hardware hw = ht.newHardware();
			if (setAll)
			{
				hw.setName("Test hardware");
				hw.setDescription("Added at "+new Date());
				hw.setVersionString("v2.0");
			}
			if (name != null) hw.setName(name);
			dc.saveItem(hw);
			dc.commit();
			id = hw.getId();
			dc = TestUtil.getDbControl();
			dc.reattachItem(hw);
			write_item(0, hw);
			write("--Create hardware OK");
		}
		catch (Throwable ex)
		{
			write("--Create hardware FAILED");
			ex.printStackTrace();
			ok = false;
		}
		finally
		{
			if (dc != null) dc.close();
		}
		return id;
	}

	static void test_load(int id)
	{
		if (id == 0) return;
		DbControl dc = null;
		try
		{
			dc = TestUtil.getDbControl();
			Hardware hw = Hardware.getById(dc, id);
			write_item(0, hw);
			write("--Load hardware OK");
		}
		catch (Throwable ex)
		{
			write("--Load hardware FAILED");
			ex.printStackTrace();
			ok = false;
		}
		finally
		{
			if (dc != null) dc.close();
		}
	}

	static void test_list()
	{
		DbControl dc = null;
		try
		{
			dc = TestUtil.getDbControl();
			ItemResultList<Hardware> l = Hardware.getQuery().list(dc);
			for (int i = 0; i<l.size(); i++)
			{
				write_item(i, l.get(i));
			}
			write("--List hardware OK ("+l.size()+")");
		}
		catch (Throwable ex)
		{
			write("--List hardware FAILED");
			ex.printStackTrace();
			ok = false;
		}
		finally
		{
			if (dc != null) dc.close();
		}
	}

	static void test_delete(int id)
	{
		if (id == 0) return;
		DbControl dc = null;
		try
		{
			dc = TestUtil.getDbControl();
			Hardware hw = Hardware.getById(dc, id);
			dc.deleteItem(hw);
			dc.commit();
			write("--Delete hardware OK");
		}
		catch (Throwable ex)
		{
			write("--Delete hardware FAILED");
			ex.printStackTrace();
			ok = false;
		}
		finally
		{
			if (dc != null) dc.close();
		}
	}
	
	static void write_header()
	{
		if (!TestUtil.getSilent())
		{
			write("   \tID \tName      \tDescription\tType\tVersion");
			write("-- \t-- \t--------- \t-----------\t----\t-------");
		}
	}
	static void write_item(int i, Hardware hw)
		throws BaseException
	{
		if (!TestUtil.getSilent()) System.out.println(i+":\t"+hw.getId()+"\t"+hw.getName()+"\t"+
			hw.getDescription()+"\t"+hw.getHardwareType().getName()+"\t"+hw.getVersionString());
	}
	static void write(String message)
	{
		System.out.println(message);
	}
}
