import java.util.Arrays;

import net.sf.basedb.core.ArrayDesign;
import net.sf.basedb.core.BaseException;
import net.sf.basedb.core.DbControl;
import net.sf.basedb.core.File;
import net.sf.basedb.core.Item;
import net.sf.basedb.core.Job;
import net.sf.basedb.core.ParameterType;
import net.sf.basedb.core.Permission;
import net.sf.basedb.core.Platform;
import net.sf.basedb.core.PluginConfigurationRequest;
import net.sf.basedb.core.PluginDefinition;
import net.sf.basedb.core.PluginParameter;
import net.sf.basedb.core.PluginResponse;
import net.sf.basedb.core.RequestInformation;
import net.sf.basedb.core.plugin.Response;

/*
 $Id$

	Copyright (C) 2006 Johan Enell, Jari Hakkinen, Nicklas Nordborg
 
	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

 BASE is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation; either version 3
 of the License, or (at your option) any later version.

 BASE is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place - Suite 330,
 Boston, MA  02111-1307, USA.
 */

/**
 
 @base.modified $Date$
 @author Enell
 @version 2.0
 */
public class TestPrintMapFlatFileImporter
{
	static boolean ok = true;

	public static void main(String[] args)
	{
		TestUtil.checkArgs(args);
		TestUtil.begin();
		test_all();
		TestUtil.stop();
	}

	static boolean test_all()
	{
		write("++Testing print map import using plugin");
		
		// Import reporters
		TestReporter.test_import_from_file("data/test.rawdata.import.txt", "\"Block\"\\t\"Column\"\\t\"Row\"\\t\"Name\"\\t\"ID\".*", "\\t", 4, 3);
		
		// Create ArrayDesign needed for print map import
		int arrayDesignId = TestArrayDesign.test_create(Platform.GENERIC, false);
		int plateGeometryId = TestPlateGeometry.test_create(16, 24, false);
		int plateTypeId = TestPlateType.test_create(plateGeometryId, false);
		int plate384 = TestPlate.test_create(plateTypeId, true);
		int[] plates = new int[4];
		Arrays.fill(plates, plate384);
		TestArrayDesign.test_add_plates(arrayDesignId, plates);
		TestArrayDesign.test_list_plates(arrayDesignId, 4);

		// Print map import
		int fileId = TestFile.test_create("data/test.parse.printmap.tam", false, false);
		int printMapPluginDefinitionId  = TestPluginDefinition.test_get("net.sf.basedb.plugins.PrintMapFlatFileImporter");
		int jobId = test_create_job_printmap(printMapPluginDefinitionId, fileId, arrayDesignId);
		
		// Execute job
		ok &= TestJob.test_execute(jobId);
		
		// Print result
		TestArrayDesign.write_feature_header();
		TestArrayDesign.test_list_features(arrayDesignId, -1);

		if (TestUtil.waitBeforeDelete()) TestUtil.waitForEnter();
		
		TestArrayDesign.test_delete(arrayDesignId);
		TestJob.test_delete(jobId);
		TestPlate.test_delete(plate384);
		TestPlateType.test_delete(plateTypeId);
		TestPlateGeometry.test_delete(plateGeometryId);
		TestReporter.test_delete();
		TestFile.test_delete(fileId);

		write("++Testing print map import using plugin "+(ok ? "OK" : "Failed")+"\n");
		return ok;
	}
	
	
	static int test_create_job_printmap(int pluginDefinitionId, int fileId, int arrayDesignId)
	{
		if (pluginDefinitionId == 0 || fileId == 0 || arrayDesignId == 0 || !TestUtil.hasPermission(Permission.CREATE, Item.JOB)) return 0;
		int id = 0;
		DbControl dc = null;
		try
		{
			dc = TestUtil.getDbControl();

			PluginDefinition pd = PluginDefinition.getById(dc, pluginDefinitionId);
			Job j = Job.getNew(dc, pd, null, null);
			j.setName(pd.getName());
			
			PluginConfigurationRequest request = j.configure(null);
			write_request_information(request.getRequestInformation());
			request.setParameterValue("file", File.getById(dc, fileId));
			request.setParameterValue("arrayDesign", ArrayDesign.getById(dc, arrayDesignId));
			
			PluginResponse response = request.invoke();
			if (response.getStatus() == Response.Status.DONE)
			{
				response.saveParameters(dc);
				dc.saveItem(j);
				dc.commit();
			}
			else
			{
				throw new BaseException(response.getMessage(), response.getErrorList().get(0));
			}
			id = j.getId();
			write("--Create job for print map import OK");
		}
		catch (Throwable ex)
		{
			write("--Create job for print map import FAILED");
			ex.printStackTrace();
			ok = false;
		}
		finally
		{
			if (dc != null) dc.close();
		}
		return id;
	}

	static void write(String message)
	{
		System.out.println(message);
	}

	static void write_request_information(RequestInformation ri)
	{
		if (TestUtil.getSilent()) return;

		write("Request information for command: "+ri.getCommand());
		write("\tTitle:\t"+ri.getTitle());
		write("\tDescription:\t"+ri.getDescription());
		if (ri.getParameters() != null)
		{
			for (PluginParameter<?> pp : ri.getParameters())
			{
				ParameterType pt = pp.getParameterType();
				write("\tParameter:\t"+pp.getName() + "\t" + pp.getLabel() + "\t" + pt );
			}
		}
	}
}
