/**
	$Id: UserTest.java 4480 2008-09-05 15:16:58Z jari $

	Copyright (C) 2006 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or modify it
	under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 3 of the License, or
	(at your option) any later version.

	BASE is distributed in the hope that it will be useful, but
	WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
	General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
	02111-1307, USA. 
*/
package net.sf.basedb.test.roles;

import net.sf.basedb.core.Annotatable;
import net.sf.basedb.core.Annotation;
import net.sf.basedb.core.AnnotationSet;
import net.sf.basedb.core.AnnotationType;
import net.sf.basedb.core.ArrayDesign;
import net.sf.basedb.core.BioMaterialEvent;
import net.sf.basedb.core.BioSource;
import net.sf.basedb.core.DataFileType;
import net.sf.basedb.core.DbControl;
import net.sf.basedb.core.Experiment;
import net.sf.basedb.core.Extract;
import net.sf.basedb.core.File;
import net.sf.basedb.core.FileParameterType;
import net.sf.basedb.core.FileType;
import net.sf.basedb.core.Hybridization;
import net.sf.basedb.core.Item;
import net.sf.basedb.core.ItemParameterType;
import net.sf.basedb.core.Job;
import net.sf.basedb.core.Label;
import net.sf.basedb.core.LabeledExtract;
import net.sf.basedb.core.Platform;
import net.sf.basedb.core.PluginConfiguration;
import net.sf.basedb.core.Project;
import net.sf.basedb.core.RawBioAssay;
import net.sf.basedb.core.RawDataType;
import net.sf.basedb.core.RawDataTypes;
import net.sf.basedb.core.Sample;
import net.sf.basedb.core.Scan;
import net.sf.basedb.core.StringParameterType;
import net.sf.basedb.test.FileUtil;
import net.sf.basedb.test.PluginUtil;
import net.sf.basedb.test.TestUtil;

/**
	This class contains the tests for the regular user created
	by the root user.
	<ol>
	</ol>

	@author nicklas
	@version 2.0
	@base.modified $Date: 2008-09-05 17:16:58 +0200 (Fri, 05 Sep 2008) $
*/
public class UserTest
{
	public static boolean ok = true;
	
	/**
		Run the tests in this class.
	*/
	public static boolean run()
	{
		DbControl dc = null;
		TestUtil.write("++Entering user test\n");
		try
		{
			TestUtil.login("user", "user", false);

			// Activate project
			dc = TestUtil.getDbControl();
			Project p = Util.findProject(dc, "Project A");
			dc.close();
			TestUtil.getSessionControl().setActiveProject(p);

			// Create biomaterials
			dc = TestUtil.getDbControl();
			BioSource bioSource =  createBioSource(dc, "Biosource A", "medium");
			Sample s1 = createSample(dc, "Sample A.00h", bioSource, 0);
			Sample s2 = createSample(dc, "Sample A.24h", bioSource, 24);
			Sample sRef = createSample(dc, "Sample A.ref", null, null);
			
			Extract e1 = createExtract(dc, "Extract A.00h", s1);
			Extract e2 = createExtract(dc, "Extract A.24h", s2);
			Extract eRef = createExtract(dc, "Extract A.ref", sRef);
			
			Label cy3 = Util.findLabel(dc, "cy3");			
			Label cy5 = Util.findLabel(dc, "cy5");			
			LabeledExtract le1 = createLabeledExtract(dc, "Labeled extract A.00h", e1, cy3);
			LabeledExtract le2 = createLabeledExtract(dc, "Labeled extract A.24h", e2, cy3);
			LabeledExtract leRef = createLabeledExtract(dc, "Labeled extract A.ref", eRef, cy5);
			LabeledExtract le1DyeSwap = createLabeledExtract(dc, "Labeled extract A.00h (dye-swap)", e1, cy5);
			LabeledExtract le2DyeSwap = createLabeledExtract(dc, "Labeled extract A.24h (dye-swap)", e2, cy5);
			LabeledExtract leRefDyeSwap = createLabeledExtract(dc, "Labeled extract A.ref (dye-swap)", eRef, cy3);
			dc.commit();
			
			// Hybridizations, etc.
			dc = TestUtil.getDbControl();
			Hybridization h1 = createHybridization(dc, "Hybridization A.00h", "Array slide A.1", le1, leRef);
			Hybridization h2 = createHybridization(dc, "Hybridization A.24h", "Array slide A.2", le2, leRef);
			Hybridization h1DyeSwap = createHybridization(dc, "Hybridization A.00h (dye-swap)", "Array slide A.3", le1DyeSwap, leRefDyeSwap);
			Hybridization h2DyeSwap = createHybridization(dc, "Hybridization A.24h (dye-swap)", "Array slide A.4", le2DyeSwap, leRefDyeSwap);

			// Affymetrix
			Hybridization affyHyb1 = createHybridization(dc, "Affymetrix hyb A.1", "Affymetrix slide A.1", le1);
			Hybridization affyHyb2 = createHybridization(dc, "Affymetrix hyb A.2", "Affymetrix slide A.2", le2);
			Hybridization affyHyb3 = createHybridization(dc, "Affymetrix hyb A.3", "Affymetrix slide A.3", leRef);
			
			Scan sc1 = createScan(dc, "Scan A.00h", h1);
			Scan sc2 = createScan(dc, "Scan A.24h", h2);
			Scan sc1DyeSwap = createScan(dc, "Scan A.00h (dye-swap)", h1DyeSwap);
			Scan sc2DyeSwap = createScan(dc, "Scan A.24h (dye-swap)", h2DyeSwap);

			// Affymetrix
			Scan affyScan1 = createScan(dc, "Affymetrix scan A.1", affyHyb1);
			Scan affyScan2 = createScan(dc, "Affymetrix scan A.2", affyHyb2);
			Scan affyScan3 = createScan(dc, "Affymetrix scan A.3", affyHyb3);
			dc.commit();
			
			// Images
			// TODO - when we have the image files

			// Upload raw data files
			dc = TestUtil.getDbControl();
			File rawData1 = FileUtil.uploadFile(dc, "/mouse", "genepix.mouse.v4.37k.00h.gpr", FileType.RAW_DATA);
			File rawData2 = FileUtil.uploadFile(dc, "/mouse", "genepix.mouse.v4.37k.24h.gpr", FileType.RAW_DATA);
			File rawData1DyeSwap = FileUtil.uploadFile(dc, "/mouse", "genepix.mouse.v4.37k.00h.dyeswap.gpr", FileType.RAW_DATA);
			File rawData2DyeSwap = FileUtil.uploadFile(dc, "/mouse", "genepix.mouse.v4.37k.24h.dyeswap.gpr", FileType.RAW_DATA);
			
			File affy1 = FileUtil.uploadFile(dc, "/affymetrix/E-TEST-1.ebi.ac.uk", "jos1761.cel.tar.bz2", FileType.RAW_DATA);
			File affy2 = FileUtil.uploadFile(dc, "/affymetrix/E-TEST-1.ebi.ac.uk", "jos1762.cel.tar.bz2", FileType.RAW_DATA);
			File affy3 = FileUtil.uploadFile(dc, "/affymetrix/E-TEST-1.ebi.ac.uk", "jos1763.cel.tar.bz2", FileType.RAW_DATA);
			dc.commit();
			
			// Raw bioassays
			dc = TestUtil.getDbControl();
			Platform genericPlatform = Platform.getByExternalId(dc, Platform.GENERIC);
			Platform affymetrixPlatform = Platform.getByExternalId(dc, Platform.AFFYMETRIX);
			ArrayDesign genericDesign = Util.findArrayDesign(dc, "Array design A");
			ArrayDesign affymetrixDesign = Util.findArrayDesign(dc, "Affymetrix A");
			RawDataType genepix = RawDataTypes.getSafeRawDataType("genepix");
			RawBioAssay rba1 = createRawBioAssay(dc, genericPlatform, genepix, "Raw bioassay A.00h", sc1, genericDesign);
			RawBioAssay rba2 = createRawBioAssay(dc, genericPlatform, genepix, "Raw bioassay A.24h", sc2, genericDesign);
			RawBioAssay rba1DyeSwap = createRawBioAssay(dc, genericPlatform, genepix, "Raw bioassay A.00h (dye-swap)", sc1DyeSwap, genericDesign);
			RawBioAssay rba2DyeSwap = createRawBioAssay(dc, genericPlatform, genepix, "Raw bioassay A.24h (dye-swap)", sc2DyeSwap, genericDesign);
			
			// Affymetrix raw bioassays
			RawBioAssay affyRaw1 = createRawBioAssay(dc, affymetrixPlatform, null, "Affymetrix raw A.1", affyScan1, affymetrixDesign);
			RawBioAssay affyRaw2 = createRawBioAssay(dc, affymetrixPlatform, null, "Affymetrix raw A.2", affyScan2, affymetrixDesign);
			RawBioAssay affyRaw3 = createRawBioAssay(dc, affymetrixPlatform, null, "Affymetrix raw A.3", affyScan3, affymetrixDesign);

			// Assign Affymetrix CEL files
			FileUtil.addDataFile(dc, affyRaw1, DataFileType.AFFYMETRIX_CEL, affy1, true, true);
			FileUtil.addDataFile(dc, affyRaw2, DataFileType.AFFYMETRIX_CEL, affy2, true, true);
			FileUtil.addDataFile(dc, affyRaw3, DataFileType.AFFYMETRIX_CEL, affy3, true, true);
			
			inheritAnnotations(dc, rba1, s1, bioSource);
			inheritAnnotations(dc, rba2, s2, bioSource);
			inheritAnnotations(dc, rba1DyeSwap, s1, bioSource);
			inheritAnnotations(dc, rba2DyeSwap, s2, bioSource);
			
			// Affymetrix
			inheritAnnotations(dc, affyRaw1, s1, bioSource);
			inheritAnnotations(dc, affyRaw2, s2, bioSource);
			inheritAnnotations(dc, affyRaw3, sRef);
			
			PluginConfiguration rawDataImporter = Util.findPluginConfiguration(dc, "Raw data for project A");
			PluginConfiguration rawDataImporterDyeSwap = Util.findPluginConfiguration(dc, "Raw data for project A (dye-swap)");
			dc.commit();
			
			// Import raw data
			importRawData(rawDataImporter, rawData1, rba1);
			importRawData(rawDataImporter, rawData2, rba2);
			importRawData(rawDataImporterDyeSwap, rawData1DyeSwap, rba1DyeSwap);
			importRawData(rawDataImporterDyeSwap, rawData2DyeSwap, rba2DyeSwap);
				
			// TODO - Create spot images - when we have the image files
			
			// Experiment
			dc = TestUtil.getDbControl();
			Experiment exp1 = createExperiment(dc, "Experiment A", 
				RawDataTypes.getSafeRawDataType("genepix"), rba1, rba2, rba1DyeSwap, rba2DyeSwap);
			Experiment affyExperiment = createExperiment(dc, "Affymetrix A", 
				affymetrixPlatform.getRawDataType(), affyRaw1, affyRaw2, affyRaw3);
			dc.commit();
			
			// Experiment overview and Analysis
			AnalysisTest.run("user");
			
			TestUtil.logout();
		}
		catch (Throwable t)
		{
			ok = false;
			t.printStackTrace();
		}
		finally
		{
			if (dc != null) dc.close();
		}
		TestUtil.write("++Leaving user test (" + (ok ? "OK" : "FAILED") + ")\n");
		return ok;
	}

	/**
		Create a biosource.
	*/
	public static BioSource createBioSource(DbControl dc, String name, String drugResistance)
	{
		TestUtil.write("--Creating biosource: " + name + "\n");
		BioSource bioSource = BioSource.getNew(dc);
		bioSource.setName(name);
		dc.saveItem(bioSource);
		
		if (drugResistance != null)
		{
			AnnotationType at = Util.findAnnotationType(dc, "Drug resistance", Item.BIOSOURCE);
			Util.setAnnotation(bioSource, at, drugResistance);
		}
		
		return bioSource;
	}
	
	/**
		Create a sample.
	*/
	public static Sample createSample(DbControl dc, String name, BioSource bioSource, Integer time)
	{
		TestUtil.write("--Creating sample: " + name + "\n");
		Sample sample = Sample.getNew(dc);
		sample.setName(name);
		sample.setOriginalQuantity(100.0f);
		sample.setBioSource(bioSource);
		sample.getCreationEvent().setProtocol(Util.findProtocol(dc, "Sampling A"));
		dc.saveItem(sample);
		
		if (time != null)
		{
			AnnotationType at = Util.findAnnotationType(dc, "Time (hours)", Item.SAMPLE);
			Util.setAnnotation(sample, at, time);
		}
		
		return sample;
	}
	
	/**
		Create an extract.
	*/
	public static Extract createExtract(DbControl dc, String name, Sample sample)
	{
		TestUtil.write("--Creating extract: " + name + "\n");
		Extract extract = Extract.getNew(dc);
		extract.setName(name);
		extract.setOriginalQuantity(100.0f);
		extract.setSample(sample, 50.0f);
		extract.getCreationEvent().setProtocol(Util.findProtocol(dc, "Extraction A"));
		dc.saveItem(extract);
		return extract;
	}

	/**
		Create a labeled extract.
	*/
	public static LabeledExtract createLabeledExtract(DbControl dc, String name, Extract extract, Label label)
	{
		TestUtil.write("--Creating labeled extract: " + name + "\n");
		
		LabeledExtract labeledExtract = LabeledExtract.getNew(dc, label);
		labeledExtract.setName(name);
		labeledExtract.setOriginalQuantity(100.0f);
		labeledExtract.setExtract(extract, 50.0f);
		labeledExtract.getCreationEvent().setProtocol(Util.findProtocol(dc, "Labeling A"));
		dc.saveItem(labeledExtract);
		return labeledExtract;
	}
	
	/**
		Create a hybridization.
	*/
	public static Hybridization createHybridization(DbControl dc, String name, String arraySlideName, LabeledExtract... extracts)
	{
		TestUtil.write("--Creating hybridization: " + name + "\n");
		Hybridization hyb = Hybridization.getNew(dc);
		hyb.setName(name);
		hyb.setArraySlide(Util.findArraySlide(dc, arraySlideName));
		BioMaterialEvent creationEvent = hyb.getCreationEvent();
		creationEvent.setProtocol(Util.findProtocol(dc, "Hybridization A"));
		creationEvent.setHardware(Util.findHardware(dc, "Hybridization station A"));
		for (LabeledExtract le : extracts)
		{
			creationEvent.addSource(le, 50.0f);
		}
		dc.saveItem(hyb);
		return hyb;
	}

	/**
		Create a scan.
	*/
	public static Scan createScan(DbControl dc, String name, Hybridization hyb)
	{
		TestUtil.write("--Creating scan: " + name + "\n");
		Scan scan = Scan.getNew(dc, hyb);
		scan.setName(name);
		scan.setProtocol(Util.findProtocol(dc, "Scanning A"));
		scan.setScanner(Util.findHardware(dc, "Scanner A"));
		dc.saveItem(scan);
		return scan;
	}

	/**
		Create a raw bioassay.
	*/
	public static RawBioAssay createRawBioAssay(DbControl dc, Platform platform, 
		RawDataType rawDataType, String name, Scan scan, ArrayDesign design)
	{
		TestUtil.write("--Creating raw bioassay: " + name + "\n");
		RawBioAssay rba = RawBioAssay.getNew(dc, platform, rawDataType);
		rba.setName(name);
		rba.setScan(scan);
		rba.setProtocol(Util.findProtocol(dc, "Feature extraction A"));
		rba.setSoftware(Util.findSoftware(dc, "Software A"));
		rba.setArrayDesign(design);
		dc.saveItem(rba);
		return rba;
	}
	
	/**
		Inherit all annotations from the parent.
	*/
	public static void inheritAnnotations(DbControl dc, Annotatable item, Annotatable... parents)
	{
		AnnotationSet as = item.getAnnotationSet();
		for (Annotatable parent : parents)
		{
			parent = (Annotatable)parent.getType().getById(dc, parent.getId());
			if (parent.isAnnotated())
			{
				as.inheritAnnotationSet(parent.getAnnotationSet());
			}
		}
	}
	
	/**
		Import features.
	*/
	public static void importRawData(PluginConfiguration config, File file, RawBioAssay rba)
		throws Exception
	{
		TestUtil.write("--Importing raw data from file: " + file.getName() + "\n");
		DbControl dc = TestUtil.getDbControl();
		try
		{
			config = PluginConfiguration.getById(dc, config.getId());
			Job job = Job.getNew(dc, config.getPluginDefinition(), config, null);
			job.setName("Importing data to raw bioassay: " + rba.getName());
			job.setParameterValue("file", new FileParameterType(), file);
			job.setParameterValue("rawBioAssay", 
				new ItemParameterType<RawBioAssay>(RawBioAssay.class, null), rba);
			job.setParameterValue("missingReporterError", new StringParameterType(), "null");
			job.setParameterValue("featureMismatchError", new StringParameterType(), "smart");
			dc.saveItem(job);
			dc.commit();
			PluginUtil.executeJob(job);
		}
		finally
		{
			if (dc != null) dc.close();
		}
	}

	/**
		Create an experiment.
	*/
	public static Experiment createExperiment(DbControl dc, String name, RawDataType rawDataType, RawBioAssay... rawBioAssays)
	{
		TestUtil.write("--Creating experiment: " + name + "\n");
		Experiment experiment = Experiment.getNew(dc, rawDataType);
		experiment.setName(name);
		
		for (RawBioAssay rba : rawBioAssays)
		{
			rba = RawBioAssay.getById(dc, rba.getId()); // To get the latest information
			experiment.addRawBioAssay(rba);
			
			AnnotationSet as = rba.getAnnotationSet();
			for (Annotation a : as.getAllInheritedAnnotations().list(dc))
			{
				experiment.addExperimentalFactor(a.getAnnotationType());
			}
			for (Annotation a : as.getAnnotations().list(dc))
			{
				experiment.addExperimentalFactor(a.getAnnotationType());
			}
		}
		
		dc.saveItem(experiment);
		return experiment;
	}

	
}
