/**
	$Id: Factories.java 4480 2008-09-05 15:16:58Z jari $

	Copyright (C) 2008 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place - Suite 330,
	Boston, MA  02111-1307, USA.
*/
package net.sf.basedb.ws.client;

/**
	Utility class for keeping the default factory implementations.

	@author nicklas
	@version 2.8
	@base.modified $Date: 2008-09-05 17:16:58 +0200 (Fri, 05 Sep 2008) $
*/
public class Factories
{

	private static ServiceFactory serviceFactory = new ConfigurableServiceFactory();
	
	/**
		Get the default service factory that is used when creating
		{@link SessionClient} objects when no factory has been specified
		in the constructor. The default factory is a {@link ConfigurableServiceFactory}
		with all options having default values.
		The default service factory can be changed by
		{@link #setDefaultServiceFactory(ServiceFactory)}
	 */
	public static final ServiceFactory getDefaultServiceFactory()
	{
		return serviceFactory;
	}
	
	/**
		Set the default service factory that is used when creating
		{@link SessionClient} objects when no factory has been specified
		in the constructor.
	*/
	public static final void setDefaultServiceFactory(ServiceFactory factory)
	{
		serviceFactory = factory;
	}
	
}
