/**
	$Id: ProjectClient.java 4480 2008-09-05 15:16:58Z jari $

	Copyright (C) 2007 Martin Svensson, Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place - Suite 330,
	Boston, MA  02111-1307, USA.
*/
package net.sf.basedb.ws.client;

import net.sf.basedb.info.ProjectInfo;
import net.sf.basedb.info.QueryOptions;

import org.apache.axis2.AxisFault;

/**
 	Web service client for project in BASE.
 	Calls services in {@link net.sf.basedb.ws.server.ProjectService}
  	@author Martin
  	@version 2.5
 */
public class ProjectClient 
	extends AbstractRPCClient 
{
	private final SessionClient session;
	
	/**
	 	Creates new ProjectClient object for an active session client.
	  	@param session The active session client
	 */
	public ProjectClient(SessionClient session)
	{
		super(session.getUrl(), "Project", session.getServiceFactory());
		this.session = session;
	}
	
	/**
		Get info about a project when you know the ID.
		@param itemId The ID of the project
		@return An ExperimentInfo object
		@throws AxisFault If communication with web service fails.
	*/
	public ProjectInfo getById(int itemId)
		throws AxisFault
	{
		return invokeBlocking("getById", ProjectInfo.class, 
			session.getId(), itemId);
}

	
	/**
	 	Sets a project to be active.
	  	@param projectId Id of the project that should be put active.
	  	@throws AxisFault If communication with web services fails.
	 */
	public void setActive(int projectId)
		throws AxisFault
	{
		invokeBlocking("setActiveProject", session.getId(), projectId);
	}
	
	/**
	 	Gets info about each projects that are available for the active session client.
	  	@param qOpt Options to put on the query that gets the project from database.
	  	@return An array with a info object for each project.
	  	@throws AxisFault If communication with web service fails.
	 */
	public ProjectInfo[] getProjects(QueryOptions qOpt)
		throws AxisFault
	{		 
		ProjectInfo[] result = invokeBlocking("getProjects", ProjectInfo[].class, session.getId(), qOpt);
		return result;
	}	
}
